package main

import (
	"context"
	"flag"

	"git.loafle.net/commons_go/config"
	"git.loafle.net/commons_go/logging"
	"git.loafle.net/overflow/overflow_gateway_probe/conf"
	"git.loafle.net/overflow/overflow_gateway_probe/grpc"
	"git.loafle.net/overflow/overflow_gateway_probe/handler"
	"git.loafle.net/overflow/overflow_gateway_probe/redis"
	"git.loafle.net/overflow/overflow_gateway_probe/server"
	"git.loafle.net/overflow/overflow_gateway_probe/subscribe"
)

func main() {
	configPath := flag.String("config", ".", "The path of config file")

	flag.Parse()

	config.SetConfigPath(*configPath)
	if err := config.Load(&conf.Config, "config.json"); nil != err {
		panic(err)
	}

	ctx := context.Background()

	defer logging.Logger.Sync()

	s := server.NewServer(ctx)
	rp := redis.NewPool(ctx)
	grpc.InitializePool(ctx)

	psh := handler.NewProbeSocketHandler(ctx)
	ash := handler.NewAuthSocketHandler(ctx)

	subscribe.Subscribe(ctx, rp.Get())

	s.HandleSocket(conf.Config.Handlers["probe"].Entry, psh)
	s.HandleSocket(conf.Config.Handlers["auth"].Entry, ash)

	s.ListenAndServe(conf.Config.Server.Addr)
}
